alias mAddTabGroup XmAddTabGroup
alias mArrowButton XmArrowButton
alias mArrowButtonGadget XmArrowButtonGadget
alias mBulletinBoard XmBulletinBoard
alias mBulletinBoardDialog XmBulletinBoardDialog
alias mBulletinBoard XmBulletinBoard
alias mCascadeButton XmCascadeButton
alias mCascadeButtonGadget XmCascadeButtonGadget
alias mCascadeButtonGadgetHighlight XmCascadeButtonGadgetHighlight
alias mCascadeButtonHighlight XmCascadeButtonHighlight
alias mCommand XmCommand
alias mCommandAppendValue XmCommandAppendValue
alias mCommandError XmCommandError
alias mCommandGetChild XmCommandGetChild
alias mDialogShell XmDialogShell
alias mDrawingArea XmDrawingArea
alias mDrawnButton XmDrawnButton
alias mErrorDialog XmErrorDialog
alias mMessageBox XmMessageBox
alias mFileSelectionBox XmFileSelectionBox
alias mFileSelectionBoxGetChild XmFileSelectionBoxGetChild
alias mFileSelectionDialog XmFileSelectionDialog
alias mFileSelectionBox XmFileSelectionBox
alias mFileSelectionDoSearch XmFileSelectionDoSearch
alias mForm XmForm
alias mFormDialog XmFormDialog
alias mForm XmForm
alias mFrame XmFrame
alias mGetDestination XmGetDestination
alias mInformationDialog XmInformationDialog
alias mMessageBox XmMessageBox
alias mLabel XmLabel
alias mLabelGadget XmLabelGadget
alias mList XmList
alias mListAddItem XmListAddItem
alias mListAddItems XmListAddItems
alias mListAddItemUnselected XmListAddItemUnselected
alias mListDeleteAllItems XmListDeleteAllItems
alias mListDeleteItem XmListDeleteItem
alias mListDeleteItems XmListDeleteItems
alias mListDeleteItemsPos XmListDeleteItemsPos
alias mListDeletePos XmListDeletePos
alias mListDeselectAllItems XmListDeselectAllItems
alias mListDeselectItem XmListDeselectItem
alias mListDeselectPos XmListDeselectPos
alias mListGetMatchPos XmListGetMatchPos
alias mListGetSelectedPos XmListGetSelectedPos
alias mListItemExists XmListItemExists
alias mListItemPos XmListItemPos
alias mListReplaceItems XmListReplaceItems
alias mListReplaceItemsPos XmListReplaceItemsPos
alias mListSelectItem XmListSelectItem
alias mListSelectPos XmListSelectPos
alias mListSetAddMode XmListSetAddMode
alias mListSetBottomItem XmListSetBottomItem
alias mListSetBottomPos XmListSetBottomPos
alias mListSetHorizPos XmListSetHorizPos
alias mListSetItem XmListSetItem
alias mListSetPos XmListSetPos
alias mMainWindow XmMainWindow
alias mMainWindowSetAreas XmMainWindowSetAreas
alias mMenuBar XmMenuBar
alias mRowColumn XmRowColumn
alias mMenuShell XmMenuShell
alias mMenuPosition XmMenuPosition
alias mMessageBox XmMessageBox
alias mMessageBoxGetChild XmMessageBoxGetChild
alias mMessageDialog XmMessageDialog
alias mMessageBox XmMessageBox
alias mOptionMenu XmOptionMenu
alias mRowColumn XmRowColumn
alias mPanedWindow XmPanedWindow
alias mPopupMenu XmPopupMenu
alias mRowColumn XmRowColumn
alias mProcessTraversal XmProcessTraversal
alias mPromptDialog XmPromptDialog
alias mSelectionBox XmSelectionBox
alias mPulldownMenu XmPulldownMenu
alias mRowColumn XmRowColumn
alias mPushButton XmPushButton
alias mPushButtonGadget XmPushButtonGadget
alias mQuestionDialog XmQuestionDialog
alias mMessageBox XmMessageBox
alias mRadioBox XmRadioBox
alias mRowColumn XmRowColumn
alias mRowColumn XmRowColumn
alias mScale XmScale
alias mScaleSetTicks XmScaleSetTicks
alias mScrollBar XmScrollBar
alias mScrollBarGetValues XmScrollBarGetValues
alias mScrollBarSetValues XmScrollBarSetValues
alias mScrolledList XmScrolledList
alias mList XmList
alias mScrolledText XmScrolledText
alias mText XmText
alias mScrolledWindow XmScrolledWindow
alias mScrollVisible XmScrollVisible
alias mSelectionBox XmSelectionBox
alias mSelectionBoxGetChild XmSelectionBoxGetChild
alias mSelectionDialog XmSelectionDialog
alias mSelectionBox XmSelectionBox
alias mSeparator XmSeparator
alias mSeparatorGadget XmSeparatorGadget
alias mSimpleCheckBox XmSimpleCheckBox
alias mRowColumn XmRowColumn
alias mSimpleMenuBar XmSimpleMenuBar
alias mRowColumn XmRowColumn
alias mSimpleOptionMenu XmSimpleOptionMenu
alias mRowColumn XmRowColumn
alias mSimplePopupMenu XmSimplePopupMenu
alias mRowColumn XmRowColumn
alias mSimplePulldownMenu XmSimplePulldownMenu
alias mRowColumn XmRowColumn
alias mSimpleRadioBox XmSimpleRadioBox
alias mRowColumn XmRowColumn
alias mText XmText
alias mTextClearSelection XmTextClearSelection
alias mTextCopy XmTextCopy
alias mTextCut XmTextCut
alias mTextDisableRedisplay XmTextDisableRedisplay
alias mTextEnableRedisplay XmTextEnableRedisplay
alias mTextField XmTextField
alias mTextFieldClearSelection XmTextFieldClearSelection
alias mTextFieldCopy XmTextFieldCopy
alias mTextFieldCut XmTextFieldCut
alias mTextFieldGetBaseline XmTextFieldGetBaseline
alias mTextFieldGetLastPosition XmTextFieldGetLastPosition
alias mTextFieldGetSelection XmTextFieldGetSelection
alias mTextFieldGetSelectionPosition XmTextFieldGetSelectionPosition
alias mTextFieldGetString XmTextFieldGetString
alias mTextFieldInsert XmTextFieldInsert
alias mTextFieldPaste XmTextFieldPaste
alias mTextFieldPosToXY XmTextFieldPosToXY
alias mTextFieldRemove XmTextFieldRemove
alias mTextFieldReplace XmTextFieldReplace
alias mTextFieldSetAddMode XmTextFieldSetAddMode
alias mTextFieldSetHighlight XmTextFieldSetHighlight
alias mTextFieldSetInsertionPosition XmTextFieldSetInsertionPosition
alias mTextFieldSetSelection XmTextFieldSetSelection
alias mTextFieldShowPosition XmTextFieldShowPosition
alias mTextFieldXYToPos XmTextFieldXYToPos
alias mTextFindString XmTextFindString
alias mTextGetBaseline XmTextGetBaseline
alias mTextGetLastPosition XmTextGetLastPosition
alias mTextGetSelection XmTextGetSelection
alias mTextGetSelectionPosition XmTextGetSelectionPosition
alias mTextGetString XmTextGetString
alias mTextInsert XmTextInsert
alias mTextPaste XmTextPaste
alias mTextPosToXY XmTextPosToXY
alias mTextRemove XmTextRemove
alias mTextReplace XmTextReplace
alias mTextScroll XmTextScroll
alias mTextSetAddMode XmTextSetAddMode
alias mTextSetHighlight XmTextSetHighlight
alias mTextSetInsertionPosition XmTextSetInsertionPosition
alias mTextSetSelection XmTextSetSelection
alias mTextShowPosition XmTextShowPosition
alias mTextXYToPos XmTextXYToPos
alias mToggleButton XmToggleButton
alias mToggleButtonGetState XmToggleButtonGetState
alias mToggleButtonSetState XmToggleButtonSetState
alias mToggleButtonGadget XmToggleButtonGadget
alias mToggleButtonGadgetGetState XmToggleButtonGadgetGetState
alias mToggleButtonGadgetSetState XmToggleButtonGadgetSetState
alias mUpdateDisplay XmUpdateDisplay
alias mWarningDialog XmWarningDialog
alias mMessageBox XmMessageBox
alias mWorkingDialog XmWorkingDialog
alias mMessageBox XmMessageBox
alias mActivateProtocol XmActivateProtocol
alias mDeactivateProtocol XmDeactivateProtocol
alias mGetString XmGetString
alias mChangeColor XmChangeColor
